#!/usr/bin/env python
# -*- coding: utf-8  -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2012 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################

"""
``rattail.pyramid.views.categories`` -- Category Views
"""

from edbob.pyramid.views import GridView
from edbob.pyramid.views.crud import Crud

import rattail


class CategoryGrid(GridView):

    mapped_class = rattail.Category
    route_name = 'categories.list'
    route_prefix = 'category'

    def filter_map(self):
        return self.make_filter_map(
            exact=['number'],
            ilike=['name'])

    def search_config(self, fmap):
        return self.make_search_config(
            fmap,
            include_filter_name=True,
            filter_type_name='lk')

    def grid_config(self, search, fmap):
        return self.make_grid_config(search, fmap,
                                     sort='number')

    def sort_map(self):
        return self.make_sort_map('number', 'name')

    def grid(self, data, config):
        g = self.make_grid(data, config)
        g.configure(
            include=[
                g.number,
                g.name,
                ],
            readonly=True)
        return g


class CategoryCrud(Crud):

    mapped_class = rattail.Category
    home_route = 'categories.list'
    url_prefix = '/categories'

    def fieldset(self, obj):
        fs = self.make_fieldset(obj)
        fs.configure(
            include=[
                fs.number,
                fs.name,
                ])
        return fs


def includeme(config):
    CategoryGrid.add_route(config, 'categories.list', '/categories')
    CategoryCrud.add_routes(config)
